French ECQ Paris, France May 4th 2002 40 players Stéphane Lavrut "Voters will get your death" Despite containing only 2 votes in the crypt, it manage to pass votes whatever the situation ... And this deck only contains 15 rare cards ! Crypt (12 cards, min=7, max=19, avg=3.17) ----------------------------------------- 1x Rake 6 PRE aus cel pot prince Brujah:1 1x Jazz Wentworth 5 PRE dom for Ventrue:1 1x Mariana Gilbert 4 PRE cel Toreador:1 1x Violette Prentiss 4 PRE dom Ventrue:1 1x Gideon Fontaine 3 PRE Ventrue:1 1x Itzahk Levine 3 cel pre Ventrue:2 1x Roland Loussarian 3 for pre Ventrue:1 1x Uma Hatch 3 cel pre Brujah:1 1x Delilah Easton 2 pre Toreador:1 1x Frederick the Weak 2 pre Brujah antitribu:2 1x Vasilis, The Traitor of Don Cruez 2 pre Brujah:2 1x Antoinette DuChamp 1 cel pre Caitiff:2 Library (90 cards) Master (19) 4x Archon Investigation 4x Blood Doll 1x Creepshow Casino 1x Dreams of the Sphinx 2x Hostile Takeover 3x Presence 2x Sudden Reversal 2x Ventrue Headquarters Action (11) 8x Charming Lobby 3x Entrancement Political Action (28) 1x Consanguineous Condemnation 3x Conservative Agitation 2x Disputed Territory 6x Dramatic Upheaval 5x Kine Resources Contested 5x Parity Shift 1x Praxis Seizure: Atlanta 1x Praxis Seizure: Boston 1x Praxis Seizure: Chicago 1x Praxis Seizure: Cleveland 1x Praxis Seizure: Dallas 1x Praxis Seizure: Houston Action Modifier (24) 8x Awe 5x Bewitching Oration 3x Change of Target 8x Voter Captivation Combat (8) 8x Majesty